
# Slot: default_curi_maps


ordered list of prefixcommon biocontexts to be fetched to resolve id prefixes and inline prefix variables

URI: [linkml:default_curi_maps](https://w3id.org/linkml/default_curi_maps)


## Domain and Range

[SchemaDefinition](SchemaDefinition.md) &#8594;  <sub>0..\*</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [SchemaDefinition](SchemaDefinition.md)
